# eric7.QtHelpInterface.QtHelpDocumentationConfigurationDialog

Module implementing a dialog to manage the QtHelp documentation database.

### Global Attributes

None

### Classes

QtHelpDocumentationConfigurationDialog | Class implementing a dialog to manage the QtHelp documentation database.

### Functions

None

## QtHelpDocumentationConfigurationDialog

Class implementing a dialog to manage the QtHelp documentation database.

### Derived from

QDialog, Ui_QtHelpDocumentationConfigurationDialog

### Class Attributes

None

### Class Methods

None

### Methods

QtHelpDocumentationConfigurationDialog | Constructor
__applyConfiguration | Private method to apply the current QtHelp documentation configuration.
__documentationSettingsChanged | Private slot to handle a change of the QtHelp documentation configuration.
on_buttonBox_clicked | Private slot called by a button of the button box clicked.

### Static Methods

None

#### QtHelpDocumentationConfigurationDialog (Constructor)

QtHelpDocumentationConfigurationDialog(engine, parent=None)

Constructor

engine (QHelpEngineCore)
  reference to the Qt help engine
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### QtHelpDocumentationConfigurationDialog.__applyConfiguration

__applyConfiguration()

Private method to apply the current QtHelp documentation configuration.

#### QtHelpDocumentationConfigurationDialog.__documentationSettingsChanged

__documentationSettingsChanged(settings)

Private slot to handle a change of the QtHelp documentation configuration.

settings (QtHelpDocumentationSettings)
  reference to the documentation settings object

#### QtHelpDocumentationConfigurationDialog.on_buttonBox_clicked

on_buttonBox_clicked(button)

Private slot called by a button of the button box clicked.

button (QAbstractButton)
  button that was clicked

Up